Cleanup/wg init (#260)
* remove wg_init and wg_finalize from functional tests
* Remove wg_init and wg_finalize from examples
* deprecate wg_init/finalize
* Updated docs
* Typo in documentation
---------
Co-authored-by: Yiltan <yiltan@amd.com>
[ROCm/rocshmem commit: 6e7277b544]
This commit is contained in:
committad av
GitHub
förälder
192c549d40
incheckning
8837414042
@@ -36,7 +36,6 @@ __global__ void SyncTest(int loop, int skip, long long int *start_time,
|
||||
int wg_id = get_flat_grid_id();
|
||||
int wf_id = t_id / wf_size;
|
||||
|
||||
rocshmem_wg_init();
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
|
||||
for (int i = 0; i < loop + skip; i++) {
|
||||
@@ -69,7 +68,6 @@ __global__ void SyncTest(int loop, int skip, long long int *start_time,
|
||||
}
|
||||
|
||||
rocshmem_wg_ctx_destroy(&ctx);
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
/******************************************************************************
|
||||
|
||||
Referens i nytt ärende
Block a user